==> py312-contourpy-1.2.0_0.darwin_12.x86_64.tbz2: opt/local/Library/Frameworks/Python.framework/Versions/3.12/lib/python3.12/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"/usr/local/lib/python3.12/site-packages/",
        python_path=r"/opt/local/Library/Frameworks/Python.framework/Versions/3.12/bin/python3.12",

        # Package versions
        contourpy_version="1.2.0",
        meson_version="1.2.3",
        mesonpy_version="0.15.0",
        pybind11_version="2.11.1",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.2.0/.mesonpy-4wbq_8u4/lib/contourpy/util",
        source_dir=r"/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.2.0/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.2.0/.mesonpy-4wbq_8u4/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="clang",
        compiler_version="16.0.6",
        linker_id="ld64",
        compile_command="/opt/local/bin/clang++-mp-16",

        # Host machine
        host_cpu="x86_64",
        host_cpu_family="x86_64",
        host_cpu_endian="little",
        host_cpu_system="darwin",

        # Build machine, same as host machine if not a cross_build
        build_cpu="x86_64",
        build_cpu_family="x86_64",
        build_cpu_endian="little",
        build_cpu_system="darwin",
    )

==> py312-contourpy-1.2.1_0.darwin_12.x86_64.tbz2: opt/local/Library/Frameworks/Python.framework/Versions/3.12/lib/python3.12/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"/usr/local/lib/python3.12/site-packages/",
        python_path=r"/opt/local/Library/Frameworks/Python.framework/Versions/3.12/bin/python3.12",

        # Package versions
        contourpy_version="1.2.1",
        meson_version="1.4.0",
        mesonpy_version="0.15.0",
        pybind11_version="2.12.0",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.2.1/.mesonpy-k3d4ud4x/lib/contourpy/util",
        source_dir=r"/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.2.1/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.2.1/.mesonpy-k3d4ud4x/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="clang",
        compiler_version="16.0.6",
        linker_id="ld64",
        compile_command="/opt/local/bin/clang++-mp-16",

        # Host machine
        host_cpu="x86_64",
        host_cpu_family="x86_64",
        host_cpu_endian="little",
        host_cpu_system="darwin",

        # Build machine, same as host machine if not a cross_build
        build_cpu="x86_64",
        build_cpu_family="x86_64",
        build_cpu_endian="little",
        build_cpu_system="darwin",
    )
